{% load trans from i18n %}

<!doctype html>
<!--[if lt IE 7]> <html class="no-js lt-ie9 lt-ie8 lt-ie7" lang="en"> <![endif]-->
<!--[if IE 7]>    <html class="no-js lt-ie9 lt-ie8" lang="en"> <![endif]-->
<!--[if IE 8]>    <html class="no-js lt-ie9" lang="en"> <![endif]-->
<!--[if gt IE 8]><!--> <html class="no-js" lang="en"> <!--<![endif]-->
  <head>
    <meta charset="utf-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">

    <title>{% block title %}{% endblock %}{% block title_default %} | {% trans "DjangoVoice" %}{% endblock %}</title>

	<meta name="viewport" content="width=device-width">
    <link rel="shortcut icon" type="image/png" href="{{ STATIC_URL }}djangovoice/images/favicon.png" />
    <link rel="stylesheet" href="{{ STATIC_URL }}djangovoice/bootstrap/css/bootstrap.min.css" />
    <link rel="stylesheet" href="{{ STATIC_URL }}djangovoice/css/djangovoice.css" />

	<script src="{{ STATIC_URL }}djangovoice/js/libs/modernizr-2.5.3.min.js"></script>
    {% block script_base %}{% endblock %}
    {% block script %}{% endblock %}
  </head>

  <body>
    <!--[if lt IE 7]><p class=chromeframe>Your browser is <em>ancient!</em> <a href="http://browsehappy.com/">Upgrade to a different browser</a> or <a href="http://www.google.com/chromeframe/?redirect=true">install Google Chrome Frame</a> to experience this site.</p><![endif]-->
    {% block body %}{% endblock %}

    <script src="//ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js"></script>
    <script>window.jQuery || document.write('<script src="{{ STATIC_URL }}djangovoice/js/libs/jquery-1.7.2.min.js"><\/script>')</script>
    <script src="{{ STATIC_URL }}djangovoice/bootstrap/js/bootstrap.min.js"></script>
    {% block djangovoice_scripts %}{% endblock %}
  </body>
</html>
