{% load trans from i18n %}

<tr class="{{ field.html_name }}">
  <td class="input-label">
    {{ field.label_tag }}

    {% if field.field.required %}
      <span class="required">({% trans "required" %})</span>
    {% endif %}

    {% if field.help_text %}
	  <div class="form-help">
	    {{ field.help_text }}
	  </div>
    {% endif %}
  </td>

  <td class="field{% if field.errors %} field-error{% endif %}">
    {{ field }}

    {% if field.errors %}
      <div class="form-errors">{{ field.errors }}</div>
    {% endif %}
  </td>
</tr>
